#
# spec file for package go-sendxmpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           go-sendxmpp
Version:        0.14.0
Release:        1.1
Summary:        A little tool to send messages to an XMPP contact or MUC
License:        BSD-2-Clause
Group:          Productivity/Networking/Instant Messenger
URL:            https://salsa.debian.org/mdosch/go-sendxmpp
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging

%description
A little tool to send messages to an XMPP contact or MUC.

%prep
%setup -q -a1

%build
go build \
   -mod=vendor \
   -buildmode=pie

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}
install -d %{buildroot}%{_mandir}/man1
install -D -m0644 man/%{name}.1 %{buildroot}%{_mandir}/man1

%files
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Dec 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  Added:
  * Add --fast-invalidate to allow invalidating the FAST token.
  Changed:
  * Don't create legacy Ox private key directory in ~/.local/share/go-sendxmpp/oxprivkeys.
  * Delete legacy Ox private key directory if it's empty.
  * Show proper error if saved FAST mechanism isn't usable with current TLS version (requires go-xmpp >= 0.2.9).
  * Print debug output to stdout, not stderr (requires go-xmpp >= 0.2.9).
  * Show RECV: and SEND: prefix for debug output (requires go-xmpp >= 0.2.9).
  * Delete stored fast token if --fast-invalidate and --fast-off are set.
  * Show error when FAST creds are stored but non-FAST mechanism is requested.
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.13.0:
  Added:
  * Add --anonymous to support anonymous authentication (requires go-xmpp >= 0.2.8).
  * Add XEP-0480: SASL Upgrade Tasks support (requires go-xmpp >= 0.2.8).
  * Add support for see-other-host stream error (requires go-xmpp >= 0.2.8).
  Changed:
  * Don't automatically try other auth mechanisms if FAST authentication fails.
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.12.1:
  Changed:
  * Print error instead of quitting if a message of type error is received.
  * Allow upload of multiple files.
  Added:
  * Add flag --suppress-root-warning to suppress the warning when go-sendxmpp is used by the root user.
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.12.0:
  Added:
  * Add possibility to look up direct TLS connection endpoint via hostmeta2 (requires xmppsrv >= 0.3.3).
  * Add flag --allow-plain to allow PLAIN authentication (requires go-xmpp >= 0.2.5).
  Changed:
  * Disable PLAIN authentication per default.
  * Disable PLAIN authentication after first use of a SCRAM auth mechanism (overrides --allow-plain) (requires
    go-xmpp >= 0.2.5).
* Sat Oct 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.11.4:
  * Fix bug in SCRAM-SHA-256-PLUS (via go-xmpp >= 0.2.4).
* Sat Oct 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.11.3:
  * Add go-xmpp library version to --version output (requires go-xmpp >= 0.2.2).
  * Fix XEP-0474: SASL SCRAM Downgrade Protection hash calculation bug (via go-xmpp >= v0.2.3).
  * [gocritic]: Improve code quality.
* Wed Sep 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.11.2:
  * Add Gopenpgp and Xmppsrv version to --version output.
  * Improve selection between StartTLS and DirectTLS.
* Fri Jul 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.11.1:
  * Fix Ox encryption in interactive mode (do not add the same
    recipient key to the keyring over and over again).
  * Exit with error code if Ox encryption for one recipient fails.
  * Improved handling of perl sendxmpp config files.
* Fri May 31 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.11.0:
  Changed:
  * Move private Ox key into JID folder in ~/.local/share/go-sendxmpp.
  * Use fmt.Errorf() instead of errors.New() to create new error messages.
  Added:
  * Add new parameter --subject.
  * Added flag --fast-off to disable XEP-0484: Fast Authentication
    Streamlining Tokens (requires go-xmpp >= 0.2.1)
* Mon Apr 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * Fixed a race condition in receiving stanzas (requires go-xmpp >= v0.1.5).
  * Add support for SASL2 and BIND2 (via go-xmpp >= v0.2.0).
  * Add support for FAST authentication (via go-xmpp >= v0.2.0).
  * Add a warning when run by the user root.
* Fri Mar 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  Changed:
  * Properly close stream if Ctrl+C is pressed in interactive mode.
  * Properly close stream if Ctrl+C is pressed in listening mode.
  * Print OS, architecture and go version for flag --version.
  * Improve closing of connection (via go-xmpp v0.1.4).
  * Don't send stanzas that exceed the size limit provided by
    XEP-0478 (requires go-xmpp >= v0.1.4).
  * Fixed hanging forever in stream close if the server doesn't
    reply with a closing stream element (via go-xmpp >= v0.1.4).
  Added:
  * New command line flag ssdp-off to disable XEP-0474: SASL SCRAM
    Downgrade Protection (requires go-xmpp >= v0.1.4).
* Sun Mar 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.8.4:
  * Properly handle lost connection.
  * Better compatibility with perl sendxmpp config files.
  * Improve file name for private Ox keys.
  * Improve fallback behavior if no SRV records are provided.
  * Remove 100ms sleep before closing the connection. This should
    be no more needed since go-xmpp commit
    9684a8ff690f0d75e284f8845696c5057926d276.
  * Return an error if there is no answer to an IQ within 60s.
  * Check for errors after sending the auth message during
    SCRAM authentication (via go-xmpp v0.1.2).
* Mon Feb 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.8.3:
  * Use a human readable file name for private Ox keys.
  * Fix specifying a message via command line flag -m.
* Sun Jan 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.8.2:
  * Fix an issue in look up of SRV records (via xmppsrv v0.2.6)
* Wed Jan 17 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.8.1:
  * Add support for tls-server-end-point channel binding
  * Add experimental support for SOCKS5 proxies using the HTTP_PROXY
    environment variable
  * http-upload: Improved error handling.
* Tue Jan  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.8.0:
  Added:
  * Add no parameter --scram-mech-pinning.
  Changed:
  * Refuse to upload a file if upload slot doesn't provide https.
  * Use XEP-0474 instead of SCRAM mechanism pinning to prevent
    downgrade attacks
* Tue Nov 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.0:
  * Reply to XEP-0092 software version requests.
  * Add support for PLUS variants of SCRAM authentification mechanisms
    (requires go-xmpp commit 4c385a334c606e8bc387f0a3d4d84975802b3984).
  * Add pinning of last used authentification mechanism if a SCRAM
    mechanism was used.
  * Print every stanza in a new line (requires go-xmpp commit
    31c7eb6919b67b18e901dc45a8e5681040ea7f31).
* Sat Sep 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.2:
  * Properly close connection to server if ^C is pressed in
    interactive mode.
  * Replace invalid characters by UTF8 replacement char.
  * Add warning that there is no Ox support for messages of type
    headline.
  * Suppress warnings about reading from closed connection if
    go-sendxmpp closes the connection before exiting.
  * Remove unnecessary newlines after stanzas.
  * Fix segfault when authentication fails due to invalid username
    or password.
* Wed Jul 26 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.1:
  * Properly close connection to server.
* Sun Jul  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  Added:
  * Add support for sending Out of Band Data (OOB).
  * Add SCRAM-SHA-1, SCRAM-SHA-256 and SCRAM-SHA512 support (via go-xmpp commit bef3e54).
  * Add support for messages of type headline.
  Changed:
  * Print --help output to stdout instead of stderr.
  * Print sent stanzas when --debug is used (via go-xmpp commit 9129a110df1b).
  * Allow JIDs without localpart.
  * Use single quotes for attributes in stanzas created by github.com/beevik/etree (vial etree v1.1.4).
  * Fix SRV lookup when the domain has a CNAME (via xmppsrv v0.2.5).
  * Fall back to directTLS on port 5223 (instead of StartTLS on port 5222)
    if no SRV records are provided and -t is set.
  * Remove trailing newlines in interactive mode.
* Sun Nov 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.6:
  Added:
  * Add short option -h for http-upload.
  Changed:
  * Fix Ox key generation.
* Tue Oct 18 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.5:
  * Improve interactive mode.
* Fri Sep 30 2022 mvetter@suse.com
- Update to version 0.5.4:
  * Fix http-upload.
* Thu Sep 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.3:
  * Don't check for empty message when --listen is used.
* Thu Sep 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.2:
  Added:
  * Reply to disco#info queries.
  * Send service-unavailable errors for all other IQs of type get and set.
  * New config option and command line flag alias to uncouple MUC
    nickname/alias from resource.
  Changed:
  * Ox: Improve error messages for failed key requests.
  * Ox: Do not encrypt empty messages.
  * Check for empty messages.
  * Always look up CNAME before doing SRV lookups (via xmppsrv v0.2.3).
  * Detect CNAME loops (max. 5 CNAMEs) (via xmppsrv >= v0.2.4).
  * Deprecate resource config option and command line flag.
  * Improve error handling in XML parsing.
  * Don't connect to the XMPP server if the message is empty.
* Thu Aug  4 2022 Michael Vetter <mvetter@suse.com>
- Initial package of go-sendxmpp 0.5.1 for openSUSE
